@@ -35,8 +35,15 @@ macro_rules! print_queue {
 
 impl IRust {
     pub fn parse(&mut self) -> Result<PrintQueue> {
+        let buffer = self.buffer.to_string();
+        // check if a script want to act upon the input
+        // if so scripts have precedence over normal flow
+        if let Some(output) = self.output_event_hook(&buffer, &self.global_variables) {
+            return print_queue!(output, Color::Blue);
+        }
+
         // Order matters in this match
-        match self.buffer.to_string().as_str() {
+        match buffer.as_str() {
             ":help" => self.help(),
             ":reset" => self.reset(),
             ":show" => Ok(self.show()),
@@ -59,6 +66,7 @@ impl IRust {
             cmd if cmd.starts_with(":bench") => self.bench(),
             cmd if cmd.starts_with(":asm") => self.asm(),
             cmd if cmd.starts_with(":executor") => self.executor(),
+            cmd if cmd.starts_with(":scripts") => self.scripts(),
             _ => self.parse_second_order(),
         }
     }
@@ -308,6 +316,7 @@ impl IRust {
         const PUB: &str = "pub ";
         const WHILE: &str = "while ";
         const EXTERN: &str = "extern ";
+        const MACRO_RULES: &str = "macro_rules!";
 
         // attribute exp:
         // #[derive(Debug)]
@@ -334,6 +343,7 @@ impl IRust {
             || self.options.auto_insert_semicolon
                 && (buffer_trimmed.starts_with(FUNCTION_DEF)
                     || buffer_trimmed.starts_with(ASYNC_FUNCTION_DEF)
+                    || buffer_trimmed.starts_with(MACRO_RULES)
                     || buffer_trimmed.starts_with(ENUM_DEF)
                     || buffer_trimmed.starts_with(STRUCT_DEF)
                     || buffer_trimmed.starts_with(TRAIT_DEF)
@@ -348,9 +358,10 @@ impl IRust {
             let mut insert_flag = true;
 
             if self.options.check_statements {
-                if let Some(mut e) =
-                    format_check_output(self.repl.eval_check(buffer.clone())?.output)
-                {
+                self.while_compiling_hook();
+                let check_result = self.repl.eval_check(buffer.clone());
+                self.after_compiling_hook();
+                if let Some(mut e) = format_check_output(check_result?.output) {
                     print_queue.append(&mut e);
                     insert_flag = false;
                 }
@@ -359,6 +370,7 @@ impl IRust {
             // if cargo_check is disabled or if cargo_check is enabled but returned no error
             if insert_flag {
                 self.repl.insert(buffer);
+                self.repl.write_to_extern()?;
             }
 
             Ok(print_queue)
@@ -549,4 +561,11 @@ impl IRust {
             print_queue!(self.options.executor.to_string(), Color::Blue)
         }
     }
+    fn scripts(&mut self) -> Result<PrintQueue> {
+        if let Some(scripts_list) = self.scripts_list() {
+            print_queue!(scripts_list, Color::Cyan)
+        } else {
+            Err("No scripts found (this command only detects Script V3)".into())
+        }
+    }
 }
